Energym
-------

This section describes the Energym integration in Beobench.

Resources
^^^^^^^^^
- Repository: https://github.com/bsl546/energym
- Documentation: https://bsl546.github.io/energym-pages/

Licensing
^^^^^^^^^

All code is covered by the standard beobench_contrib license apart from the dockerfile in the ``beobench_contrib/energym`` folder. This dockerfile contains code that is licensed under the `LICENSE file here <https://github.com/bsl546/energym/blob/0133ca7a19d21352a427e1913755e1ebf6fd8bb6/LICENSE.txt>`_.